rubrik_tool
--------

To use, call rubrik_tool from the command line:
  $ rubrik_tool

To get started, try:
  $ rubrik_tool --help

You can also import and use the RubrikTool class in python scripts.
